### Douyin_uid_package

Douyin_uid_package is a library for obtaining tiktok uid.

~~~python
from douyin_uid_pypi import douyinuid
douyinuid = douyinuid()
douyinuid.Cookie = ''
print(douyinuid.handle())
~~~